#!/bin/bash
set -e

if [ "$#" -ne 2 ]; then
    echo "need 2 parameters : python_version and openssl_version"
    echo "example : 3.8.16 3.1.3"
    exit
fi

python_version="$1"
openssl_version="$2"

export LANG=C
rm -Rf /opt/python38/
#rm -Rf Python*
#rm -Rf openssl*
#rm -Rf krb5*

#make and install openssl

cd
#wget https://www.openssl.org/source/openssl-${openssl_version}.tar.gz
tar -zxvf openssl-${openssl_version}.tar.gz
cd openssl-${openssl_version}
./config --prefix=/opt/python38  -Wl,-rpath,/opt/python38/lib/ --libdir=/opt/python38/lib
make -j`nproc`  >> /root/debug_compile_python 2>&1
make install_sw  >> /root/debug_compile_python 2>&1

#compile p11
cd
tar -zxvf libp11-0.4.12.tar.gz
cd libp11-libp11-0.4.12/
./bootstrap
./configure --prefix=/opt/python38 LDFLAGS="-Wl,-rpath,/opt/python38/lib/" PKG_CONFIG_PATH=/opt/python38/lib/pkgconfig/
make install 

#make and install python

cd
#wget https://www.python.org/ftp/python/${python_version}/Python-${python_version}.tgz
tar -zxvf Python-${python_version}.tgz
cd Python-${python_version}
./configure -C --with-openssl=/opt/python38/ --enable-optimizations --enable-shared --prefix=/opt/python38 LDFLAGS=-Wl,-rpath,/opt/python38/lib/
make -j`nproc` install >> /root/debug_compile_python 2>&1
rm -f /opt/python38/bin/{2to3,2to3-3.8,idle3,idle3.8} 

#make and install mit kerberos

cd
#wget https://kerberos.org/dist/krb5/1.19/krb5-1.21.2.tar.gz
tar -zxvf krb5-1.21.2.tar.gz
cd krb5-1.21.2/src
./configure  --prefix=/opt/python38 LDFLAGS="-Wl,-rpath,/opt/python38/lib/" PKG_CONFIG_PATH=/opt/python38/lib/pkgconfig/ 
make -j`nproc` >> /root/debug_compile_python 2>&1
make install >> /root/debug_compile_python 2>&1
rm -f /opt/python38/bin/{gss-client,k5srvutil,kadmin,kdestroy,kinit,klist,kpasswd,ksu,kswitch,ktutil,kvno,sclient,sim_client,uuclient}
rm -Rf /opt/python38/{sbin,share,var}
rm -Rf /opt/python38/lib/python3.8/test
/opt/python38/bin/python3 -m pip install --upgrade pip
/opt/python38/bin/python3 -m pip install wheel

#/opt/python38/bin/python3 -m pip install whell
#export PATH=$PATH:/opt/python38/bin/ ; /opt/python38/bin/python3 -m pip install -r /root/requirements.txt
exit